.. currentmodule:: scippnexus

Classes
=======

Data Structures
---------------

.. autosummary::
   :toctree: ../generated/classes
   :template: scipp-class-template.rst
   :recursive:

   Field
   File
   NXdata
   NXdetector
   NXdisk_chopper
   NXentry
   NXevent_data
   NXinstrument
   NXlog
   NXmonitor
   NXobject
   NXroot
   NXsample
   NXsource
   NXtransformations

Exceptions
----------

.. autosummary::
   :toctree: ../generated/classes
   :template: scipp-class-template.rst
   :recursive:

   NexusStructureError

Typing
------

.. autosummary::
   :toctree: ../generated/classes
   :template: scipp-class-template.rst
   :recursive:

   typing.H5Dataset
   typing.H5Group
   typing.ScippIndex
